@@ -1,12 +1,17 @@
+# pragma: no cover
 import os
+import warnings
 from typing import List
 
-from esteid.bdoc2.container import BDoc2File
-from esteid.bdoc2.exceptions import NoFilesToSign
-from esteid.digidocservice.service import DataFile
+from pyasice import Container
+
+from esteid.types import DataFile
 
 
-SESSION_KEY = '__esteid_session'
+warnings.warn("This module is deprecated. Please use the new API", DeprecationWarning)
+
+
+SESSION_KEY = "__esteid_session"
 
 
 class EsteidSessionError(Exception):
@@ -32,14 +37,14 @@ def update_esteid_session(request, **kwargs):
 def delete_esteid_session(request):
     session_data = request.session.pop(SESSION_KEY, {})
 
-    temp_signature_file = session_data.get('temp_signature_file')
+    temp_signature_file = session_data.get("temp_signature_file")
     if temp_signature_file:
         try:
             os.unlink(temp_signature_file)
         except OSError:
             pass
 
-    temp_container_file = session_data.get('temp_container_file')
+    temp_container_file = session_data.get("temp_container_file")
     if temp_container_file:
         try:
             os.unlink(temp_container_file)
@@ -51,12 +56,12 @@ def open_container(container_path: str = None, files_to_sign: List[DataFile] = N
     """Open an existing BDoc container, or create a container with files to sign"""
     if container_path:
         # Take files from an existing container, ignore files_to_sign
-        container = BDoc2File(container_path)
+        container = Container.open(container_path)
     elif files_to_sign:
-        container = BDoc2File()
+        container = Container()
         for data_file in files_to_sign:
             container.add_file(data_file.file_name, data_file.content, data_file.mimetype)
     else:
-        raise NoFilesToSign('No files to sign')  # this is a 500 error because it's not the user's fault
+        raise ValueError("No files to sign")  # this is a 500 error because it's not the user's fault
 
     return container
